==> vertx-auth-oauth2-3.4.0.Beta1-sources.jar: io/vertx/groovy/ext/auth/oauth2/OAuth2Auth_GroovyExtension.java <==
package io.vertx.groovy.ext.auth.oauth2;
public class OAuth2Auth_GroovyExtension {
  public static java.lang.String authorizeURL(io.vertx.ext.auth.oauth2.OAuth2Auth j_receiver, java.util.Map<String, Object> params) {
    return j_receiver.authorizeURL(params != null ? io.vertx.lang.groovy.ConversionHelper.toJsonObject(params) : null);
  }
  public static void getToken(io.vertx.ext.auth.oauth2.OAuth2Auth j_receiver, java.util.Map<String, Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.auth.oauth2.AccessToken>> handler) {
    j_receiver.getToken(params != null ? io.vertx.lang.groovy.ConversionHelper.toJsonObject(params) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.auth.oauth2.AccessToken>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.auth.oauth2.AccessToken> ar) {
        handler.handle(ar.map(event -> io.vertx.lang.groovy.ConversionHelper.wrap(event)));
      }
    } : null);
  }
  public static io.vertx.ext.auth.oauth2.OAuth2Auth api(io.vertx.ext.auth.oauth2.OAuth2Auth j_receiver, io.vertx.core.http.HttpMethod method, java.lang.String path, java.util.Map<String, Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> handler) {
    io.vertx.lang.groovy.ConversionHelper.wrap(j_receiver.api(method,
      path,
      params != null ? io.vertx.lang.groovy.ConversionHelper.toJsonObject(params) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.core.json.JsonObject>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.core.json.JsonObject> ar) {
        handler.handle(ar.map(event -> io.vertx.lang.groovy.ConversionHelper.fromJsonObject(event)));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.auth.oauth2.OAuth2Auth introspectToken(io.vertx.ext.auth.oauth2.OAuth2Auth j_receiver, java.lang.String token, java.lang.String tokenType, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> handler) {
    io.vertx.lang.groovy.ConversionHelper.wrap(j_receiver.introspectToken(token,
      tokenType,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.core.json.JsonObject>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.core.json.JsonObject> ar) {
        handler.handle(ar.map(event -> io.vertx.lang.groovy.ConversionHelper.fromJsonObject(event)));
      }
    } : null));
    return j_receiver;
  }
}

==> vertx-auth-oauth2-3.5.0.Beta1-sources.jar: io/vertx/groovy/ext/auth/oauth2/OAuth2Auth_GroovyExtension.java <==
package io.vertx.groovy.ext.auth.oauth2;
public class OAuth2Auth_GroovyExtension {
  public static java.lang.String authorizeURL(io.vertx.ext.auth.oauth2.OAuth2Auth j_receiver, java.util.Map<String, Object> params) {
    return j_receiver.authorizeURL(params != null ? io.vertx.core.impl.ConversionHelper.toJsonObject(params) : null);
  }
  public static void getToken(io.vertx.ext.auth.oauth2.OAuth2Auth j_receiver, java.util.Map<String, Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.auth.oauth2.AccessToken>> handler) {
    j_receiver.getToken(params != null ? io.vertx.core.impl.ConversionHelper.toJsonObject(params) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.auth.oauth2.AccessToken>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.auth.oauth2.AccessToken> ar) {
        handler.handle(ar.map(event -> io.vertx.core.impl.ConversionHelper.fromObject(event)));
      }
    } : null);
  }
  public static io.vertx.ext.auth.oauth2.OAuth2Auth api(io.vertx.ext.auth.oauth2.OAuth2Auth j_receiver, io.vertx.core.http.HttpMethod method, java.lang.String path, java.util.Map<String, Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.api(method,
      path,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonObject(params) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.core.json.JsonObject>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.core.json.JsonObject> ar) {
        handler.handle(ar.map(event -> io.vertx.core.impl.ConversionHelper.fromJsonObject(event)));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.auth.oauth2.OAuth2Auth introspectToken(io.vertx.ext.auth.oauth2.OAuth2Auth j_receiver, java.lang.String token, java.lang.String tokenType, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.introspectToken(token,
      tokenType,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.core.json.JsonObject>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.core.json.JsonObject> ar) {
        handler.handle(ar.map(event -> io.vertx.core.impl.ConversionHelper.fromJsonObject(event)));
      }
    } : null));
    return j_receiver;
  }
}
